@@ -1,8 +1,8 @@
 import platform
 
 from .__version__ import __author__, __copyright__, __email__, __license__, __version__
-from ._const import AnsiBackColor, AnsiForeColor, AnsiStyle
-from ._truecolor import Color, tcolor
+from ._const import AnsiBGColor, AnsiFGColor, AnsiStyle
+from ._truecolor import Color, tcolor, RGBTuple
 
 
 if platform.system() == "Windows":
